# TranSpa
This tool implements Spatially-Regularized Translation for imputing spatial transcriptomics (TransImpSpa), and translation based cell type deconvolution (TransDeconv). Experiments reported in the manuscript are displayed in jupyter notebooks under [notebooks](https://github.com/qiaochen/tranSpa/tree/analysis/notebooks) folder.


## Installation
Under project root `tranSpa/`

```
pip install .
```

## Data
Data used and generated in the notebooks can be downloaded from [Zenodo](https://zenodo.org/record/7556184#.Y8tfmXZBxD8)
To run the notebooks, please extract the root folders as sibling folders to `tranSpa`, which should be `../data` and `../output` relative to the `README.md` file




